@@ -6,11 +6,10 @@ test_that("Test print.PlotSummary.AlphaPart", {
                      mid=c(  0,   0,   1,   0,   3,   0),
                      loc=c("A", "A", "C", "B", "C", "C"),
                     trt1=c(100, 120, 115, 130, 125, 125),
-                    trt2=c(100, 110, 105, 100,  85, 110),
                      gen=c(  1,   1,   2,   2,   3,   3))
 
   ## Partition additive genetic values
-  tmp <- AlphaPart(x=ped, colBV=c("trt1", "trt2"), center = FALSE)
+  tmp <- AlphaPart(x=ped, colBV="trt1", center = FALSE)
   sum <- summary(tmp, by="gen")
   k <- print(plot.summaryAlphaPart(sum))
   expect_equal(k,NULL)
